@@ -11,7 +11,7 @@ static inline ut8 r_read_ble8(const void *src) {
 	if (!src) {
 		return UT8_MAX;
 	}
-	return *(ut8 *)src;
+	return *(const ut8 *)src;
 }
 
 static inline ut8 r_read_at_ble8(const void *src, size_t offset) {
@@ -57,7 +57,7 @@ static inline ut16 r_read_at_be16(const void *src, size_t offset) {
 
 static inline void r_write_be16(void *dest, ut16 val) {
 	r_write_be8 (dest, val >> 8);
-	r_write_at_be8 (dest, val >> 0, sizeof (ut8));
+	r_write_at_be8 (dest, (ut8)val, sizeof (ut8));
 }
 
 static inline void r_write_at_be16(void *dest, ut16 val, size_t offset) {
@@ -78,14 +78,14 @@ static inline ut32 r_read_at_be32(const void *src, size_t offset) {
 
 static inline void r_write_be32(void *dest, ut32 val) {
 	r_write_be16 (dest, val >> 16);
-	r_write_at_be16 (dest, val >> 0, sizeof (ut16));
+	r_write_at_be16 (dest, val, sizeof (ut16));
 }
 
 static inline void r_write_be24(void *_dest, ut32 val) {
 	ut8 *dest = (ut8*)_dest;
 	r_write_be8 (dest++, val >> 16);
 	r_write_be8 (dest++, val >> 8);
-	r_write_be8 (dest, val >> 0);
+	r_write_be8 (dest, val);
 }
 
 static inline void r_write_at_be32(void *dest, ut32 val, size_t offset) {
@@ -106,7 +106,7 @@ static inline ut64 r_read_at_be64(const void *src, size_t offset) {
 
 static inline void r_write_be64(void *dest, ut64 val) {
 	r_write_be32 (dest, val >> 32);
-	r_write_at_be32 (dest, val >> 0, sizeof (ut32));
+	r_write_at_be32 (dest, (ut32)val, sizeof (ut32));
 }
 
 static inline void r_write_at_be64(void *dest, ut64 val, size_t offset) {
@@ -152,7 +152,7 @@ static inline ut16 r_read_at_le16(const void *src, size_t offset) {
 }
 
 static inline void r_write_le16(void *dest, ut16 val) {
-	r_write_le8 (dest, val >> 0);
+	r_write_le8 (dest, (ut8)val);
 	r_write_at_le8 (dest, val >> 8, sizeof (ut8));
 }
 
@@ -163,7 +163,7 @@ static inline void r_write_at_le16(void *dest, ut16 val, size_t offset) {
 
 static inline void r_write_le24(void *_dest, ut32 val) {
 	ut8* dest = (ut8*)_dest;
-	r_write_le8 (dest++, val >> 0);
+	r_write_le8 (dest++, val);
 	r_write_le8 (dest++, val >> 8);
 	r_write_le8 (dest,   val >> 16);
 }
@@ -186,7 +186,7 @@ static inline ut32 r_read_at_le32(const void *src, size_t offset) {
 }
 
 static inline void r_write_le32(void *dest, ut32 val) {
-	r_write_le16 (dest, val >> 0);
+	r_write_le16 (dest, val);
 	r_write_at_le16 (dest, val >> 16, sizeof (ut16));
 }
 
@@ -207,7 +207,7 @@ static inline ut64 r_read_at_le64(const void *src, size_t offset) {
 }
 
 static inline void r_write_le64(void *dest, ut64 val) {
-	r_write_le32 (dest, val >> 0);
+	r_write_le32 (dest, (ut32)val);
 	r_write_at_le32 (dest, val >> 32, sizeof (ut32));
 }
 
@@ -216,6 +216,98 @@ static inline void r_write_at_le64(void *dest, ut64 val, size_t offset) {
 	r_write_le64 (d, val);
 }
 
+/* Middle Endian functions. */
+
+static inline ut8 r_read_me8(const void *src) {
+	return src ? r_read_ble8 (src): UT8_MAX;
+}
+
+static inline ut8 r_read_at_me8(const void *src, size_t offset) {
+	return r_read_at_ble8 (src, offset);
+}
+
+static inline void r_write_me8(void *dest, ut8 val) {
+	r_write_ble8 (dest, val);
+}
+
+static inline void r_write_at_me8(void *dest, ut8 val, size_t offset) {
+	r_write_at_ble8 (dest, val, offset);
+}
+
+static inline ut16 r_read_me16(const void *src) {
+	if (!src) {
+		return UT16_MAX;
+	}
+	const ut8 *s = (const ut8*)src;
+	return (((ut16)s[0]) << 8) | (((ut16)s[1]) << 0);
+}
+
+static inline ut16 r_read_at_me16(const void *src, size_t offset) {
+	if (!src) {
+		return UT16_MAX;
+	}
+	const ut8 *s = (const ut8*)src + offset;
+	return r_read_me16 (s);
+}
+
+static inline void r_write_me16(void *dest, ut16 val) {
+	r_write_me8 (dest, val >> 8);
+	r_write_at_me8 (dest, (ut8)val, sizeof (ut8));
+}
+
+static inline void r_write_at_me16(void *dest, ut16 val, size_t offset) {
+	ut8 *d = (ut8 *)dest + offset;
+	r_write_me16 (d, val);
+}
+
+static inline ut32 r_read_me32(const void *src) {
+	if (!src) {
+		return UT32_MAX;
+	}
+	const ut8 *s = (const ut8*)src;
+	return (((ut32)s[2]) << 24) | (((ut32)s[1]) << 16) |
+		(((ut32)s[0]) << 8) | (((ut32)s[1]) << 0);
+}
+
+static inline ut32 r_read_at_me32(const void *src, size_t offset) {
+	if (!src) {
+		return UT32_MAX;
+	}
+	const ut8 *s = (const ut8*)src + offset;
+	return r_read_me32 (s);
+}
+
+static inline void r_write_me32(void *dest, ut32 val) {
+	r_write_me16 (dest, val);
+	r_write_at_me16 (dest, val >> 16, sizeof (ut16));
+}
+
+static inline void r_write_at_me32(void *dest, ut32 val, size_t offset) {
+	ut8 *d = ((ut8*)dest) + offset;
+	r_write_me32 (d, val);
+}
+
+static inline ut64 r_read_me64(const void *src) {
+	ut64 val = ((ut64)(r_read_at_me32 (src, sizeof (ut32)))) <<  32;
+	val |= r_read_me32 (src);
+	return val;
+}
+
+static inline ut64 r_read_at_me64(const void *src, size_t offset) {
+	const ut8 *s = ((const ut8*)src) + offset;
+	return r_read_me64 (s);
+}
+
+static inline void r_write_me64(void *dest, ut64 val) {
+	r_write_me32 (dest, (ut32)val);
+	r_write_at_me32 (dest, val >> 32, sizeof (ut32));
+}
+
+static inline void r_write_at_me64(void *dest, ut64 val, size_t offset) {
+	ut8 *d = (ut8*)dest + offset;
+	r_write_me64 (d, val);
+}
+
 /* Helper functions */
 
 static inline ut16 r_read_ble16(const void *src, bool big_endian) {
@@ -230,10 +322,22 @@ static inline ut64 r_read_ble64(const void *src, bool big_endian) {
 	return big_endian? r_read_be64 (src): r_read_le64 (src);
 }
 
+static inline ut16 r_read_at_ble16(const void *src, size_t offset, bool big_endian) {
+	return big_endian ? r_read_at_be16 (src, offset) : r_read_at_le16 (src, offset);
+}
+
+static inline ut32 r_read_at_ble32(const void *src, size_t offset, bool big_endian) {
+	return big_endian ? r_read_at_be32 (src, offset) : r_read_at_le32 (src, offset);
+}
+
+static inline ut64 r_read_at_ble64(const void *src, size_t offset, bool big_endian) {
+	return big_endian ? r_read_at_be64 (src, offset) : r_read_at_le64 (src, offset);
+}
+
 static inline ut64 r_read_ble(const void *src, bool big_endian, int size) {
 	switch (size) {
 	case 8:
-		return (ut64) ((ut8*)src)[0];
+		return (ut64) ((const ut8*)src)[0];
 	case 16:
 		return r_read_ble16 (src, big_endian);
 	case 32:
