@@ -20,6 +20,7 @@ enum {
 	R_SEARCH_STRING,
 	R_SEARCH_XREFS,
 	R_SEARCH_AES,
+	R_SEARCH_PRIV_KEY,
 	R_SEARCH_DELTAKEY,
 	R_SEARCH_MAGIC,
 	R_SEARCH_LAST
@@ -43,6 +44,12 @@ typedef struct r_search_keyword_t {
 	ut64 last; // last hit hint
 } RSearchKeyword;
 
+typedef struct r_search_uds_t {
+	ut64 addr;
+	int stride;
+	int score;
+} RSearchUds;
+
 typedef struct r_search_hit_t {
 	RSearchKeyword *kw;
 	ut64 addr;
@@ -83,6 +90,7 @@ R_API RSearch *r_search_free(RSearch *s);
 
 /* keyword management */
 R_API RList *r_search_find(RSearch *s, ut64 addr, const ut8 *buf, int len);
+R_API RList *r_search_find_uds(RSearch *search, ut64 addr, const ut8 *data, size_t size, bool verbose);
 R_API int r_search_update(RSearch *s, ut64 from, const ut8 *buf, long len);
 R_API int r_search_update_i(RSearch *s, ut64 from, const ut8 *buf, long len);
 
@@ -110,7 +118,7 @@ R_API int r_search_bmh(const RSearchKeyword *kw, const ut64 from, const ut8 *buf
 // TODO: is this an internal API?
 R_API int r_search_mybinparse_update(RSearch *s, ut64 from, const ut8 *buf, int len);
 R_API int r_search_aes_update(RSearch *s, ut64 from, const ut8 *buf, int len);
-R_API int r_search_rsa_update(RSearch *s, ut64 from, const ut8 *buf, int len);
+R_API int r_search_privkey_update(RSearch *s, ut64 from, const ut8 *buf, int len);
 R_API int r_search_magic_update(RSearch *_s, ut64 from, const ut8 *buf, int len);
 R_API int r_search_deltakey_update(RSearch *s, ut64 from, const ut8 *buf, int len);
 R_API int r_search_strings_update(RSearch *s, ut64 from, const ut8 *buf, int len);
